#' Multivariate Probabilities of Scale Mixtures of Multivariate Normal Distributions
#'
#' The QRVSN algorithm is used in a broader context: using the Genz and Bretz
#' (2002) algorithm to calculate multivariate distribution probabilities.
#'
#'
#' @section Multivariate Subgaussian Stable Distribution:
#'
#' \code{\link{pmvss}} -- multivariate subgaussian stable distribution probabilities
#'
#'
#' @docType package
#' @name mvgb
#' @useDynLib mvgb, .registration=TRUE
"_PACKAGE"

